@@ -4,7 +4,16 @@ from __future__ import annotations
 import json
 import inspect
 from types import TracebackType
-from typing import TYPE_CHECKING, Any, Generic, TypeVar, Iterator, AsyncIterator, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Generic,
+    TypeVar,
+    Iterator,
+    AsyncIterator,
+    cast,
+    Optional,
+)
 from typing_extensions import (
     Self,
     Protocol,
@@ -40,12 +49,20 @@ class Stream(Generic[_T]):
         cast_to: type[_T],
         response: httpx.Response,
         client: Ark,
+        iterator: Optional[Iterator[_T]] | None = None,
     ) -> None:
-        self.response = response
-        self._cast_to = cast_to
-        self._client = client
-        self._decoder = client._make_sse_decoder()
-        self._iterator = self.__stream__()
+        if iterator is not None:
+            self._iterator = iterator
+        else:
+            self.response = response
+            self._cast_to = cast_to
+            self._client = client
+            self._decoder = client._make_sse_decoder()
+            self._iterator = self.__stream__()
+
+    @classmethod
+    def _make_stream_from_iterator(cls, iterator: Iterator[_T]) -> Stream[_T]:
+        return Stream(cast_to=None, response=None, client=None, iterator=iterator)
 
     def __next__(self) -> _T:
         return self._iterator.__next__()
@@ -62,7 +79,9 @@ class Stream(Generic[_T]):
         response = self.response
         process_data = self._client._process_response_data
         iterator = self._iter_events()
-        request_id = self.response.headers.get(CLIENT_REQUEST_HEADER, "") if response else None
+        request_id = (
+            self.response.headers.get(CLIENT_REQUEST_HEADER, "") if response else None
+        )
 
         for sse in iterator:
             if sse.data.startswith("[DONE]"):
@@ -82,7 +101,7 @@ class Stream(Generic[_T]):
                         message=message,
                         request=self.response.request,
                         body=data["error"],
-                        request_id=request_id
+                        request_id=request_id,
                     )
 
                 yield process_data(data=data, cast_to=cast_to, response=response)
@@ -102,7 +121,7 @@ class Stream(Generic[_T]):
                         message=message,
                         request=self.response.request,
                         body=data["error"],
-                        request_id=request_id
+                        request_id=request_id,
                     )
 
                 yield process_data(
@@ -148,12 +167,20 @@ class AsyncStream(Generic[_T]):
         cast_to: type[_T],
         response: httpx.Response,
         client: AsyncArk,
+        iterator: Optional[AsyncIterator[_T]] | None = None,
     ) -> None:
-        self.response = response
-        self._cast_to = cast_to
-        self._client = client
-        self._decoder = client._make_sse_decoder()
-        self._iterator = self.__stream__()
+        if iterator is not None:
+            self._iterator = iterator
+        else:
+            self.response = response
+            self._cast_to = cast_to
+            self._client = client
+            self._decoder = client._make_sse_decoder()
+            self._iterator = self.__stream__()
+
+    @classmethod
+    def _make_stream_from_iterator(cls, iterator: AsyncIterator[_T]) -> AsyncStream[_T]:
+        return AsyncStream(cast_to=None, response=None, client=None, iterator=iterator)
 
     async def __anext__(self) -> _T:
         return await self._iterator.__anext__()
@@ -171,7 +198,9 @@ class AsyncStream(Generic[_T]):
         response = self.response
         process_data = self._client._process_response_data
         iterator = self._iter_events()
-        request_id = response.headers.get(CLIENT_REQUEST_HEADER, "") if response else None
+        request_id = (
+            response.headers.get(CLIENT_REQUEST_HEADER, "") if response else None
+        )
 
         async for sse in iterator:
             if sse.data.startswith("[DONE]"):
@@ -191,7 +220,7 @@ class AsyncStream(Generic[_T]):
                         message=message,
                         request=self.response.request,
                         body=data["error"],
-                        request_id=request_id
+                        request_id=request_id,
                     )
 
                 yield process_data(data=data, cast_to=cast_to, response=response)
@@ -211,7 +240,7 @@ class AsyncStream(Generic[_T]):
                         message=message,
                         request=self.response.request,
                         body=data["error"],
-                        request_id=request_id
+                        request_id=request_id,
                     )
 
                 yield process_data(
