@@ -423,6 +423,12 @@ default_endpoint = {
         global_endpoint='',
         region_endpoint_map={},
     ),
+    'fasttrack': ServiceEndpointInfo(
+        service='fasttrack',
+        is_global=False,
+        global_endpoint='',
+        region_endpoint_map={},
+    ),
 }
 
 bootstrap_region = {
